@@ -2,8 +2,8 @@
 
 __description__ = 'VBA summary plugin for oledump.py'
 __author__ = 'Didier Stevens'
-__version__ = '0.0.2'
-__date__ = '2015/03/11'
+__version__ = '0.0.3'
+__date__ = '2017/07/20'
 
 """
 
@@ -14,6 +14,7 @@ Use at your own risk
 History:
   2014/12/11: start
   2015/03/11: 0.0.2 stripping \r
+  2017/07/20: 0.0.3 do not select end function, end sub, exit function, exit sub
 
 Todo:
 """
@@ -31,6 +32,6 @@ class cVBASummary(cPluginParent):
     def Analyze(self):
         self.ran = True
 
-        return [line.strip('\r') for line in self.stream.split('\n') if '"' in line or 'sub' in line.lower() or 'function' in line.lower()]
+        return [line.strip('\r') for line in self.stream.split('\n') if ('"' in line or 'sub' in line.lower() or 'function' in line.lower()) and (not 'exit sub' in line.lower() and not 'exit function' in line.lower() and not 'end sub' == line.lower() and not 'end function' == line.lower())]
 
 AddPlugin(cVBASummary)
